/****************************************************************
**
** QtGantt av Gunnstein Lye
**
** This software is released under the GPL General Public License,
** see COPYING for details.
**
****************************************************************/

#include <qapplication.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qscrollbar.h>
#include <qspinbox.h>
#include <qaccel.h>
#include <qfile.h>

#include "gantt.h"


class MainWidget : public QWidget
	{
	public:
		MainWidget( char *filenamearg, QWidget *parent=0, const char *name=0 );
	protected:
		void resizeEvent( QResizeEvent * );
	private:
		QFrame *frame;
		Gantt *gantt;
		QPushButton *open, *print, *quit;
		QScrollBar *scrolltextpix;
		QSpinBox *spindaypix;
		QAccel *f5acc;
	};


MainWidget::MainWidget( char *filenamearg, QWidget *parent, const char *name )
        : QWidget( parent, name )
	{
	setMinimumSize( 490, 300 );
	
	frame = new QFrame( this, "ganttFrame" );
   frame->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
	frame->setGeometry( 5, 35, width()-10, height()-40 );
	
	gantt = new Gantt( filenamearg, this, "gantt" );
	gantt->setGeometry( 7, 37, width()-14, height()-44 );

	f5acc = new QAccel( this );    // Draws gantt when F5 is pressed
	f5acc->connectItem( f5acc->insertItem(Key_F5), gantt, SLOT( refresh() ) );
	
	open = new QPushButton( "&Open file", this, "open" );
	open->setGeometry( 5, 5, 80, 25 );
	connect( open, SIGNAL(clicked()), gantt, SLOT( open() ) );
	
	scrolltextpix = new QScrollBar( 0, 300, 1, 10, 150, QScrollBar::Horizontal, this, "scrolltextpix" );
	scrolltextpix->setGeometry( 95, 5, 150, 25 );
	connect( scrolltextpix, SIGNAL( valueChanged(int) ), gantt, SLOT(changetextpix(int)) );
	
	spindaypix = new QSpinBox( 1, 20, 1, this, "spindaypix" );
	spindaypix->setGeometry( 255, 5, 50, 25 );
	spindaypix->setValue( 3 );
	connect( spindaypix, SIGNAL( valueChanged(int) ), gantt, SLOT(changedaypix(int)) );
	
	print = new QPushButton( "&Print", this, "print" );
	print->setGeometry( 315, 5, 80, 25 );
	connect( print, SIGNAL(clicked()), gantt, SLOT( print() ) );
	
	quit = new QPushButton( "&Quit", this, "quit" );
	quit->setGeometry( width()-85, 5, 80, 25 );
	connect( quit, SIGNAL(clicked()), qApp, SLOT( quit() ) );
	}


void MainWidget::resizeEvent( QResizeEvent * )
	{
	quit->move( width()-85, 5 );
	frame->resize( width()-10, height()-40 );
	gantt->resize( width()-14, height()-44 );
	gantt->repaint();
	}


int main( int argc, char **argv )
	{
	QApplication a( argc, argv );
	
	MainWidget w( a.argv()[1] );
	w.setGeometry( 0, 80, 630, 400 );
	w.setCaption( "QtGantt" );          // Sets the caption of the window
	
	a.setMainWidget( &w );
	w.show();
	return a.exec();
	}
